@@ -198,7 +198,7 @@ class LongHandlerEN(Operation):
             if state.current_value in [':', '：'] and sub_len > self.min_sentence_length and self.blank.match(
                     state[i + 1][0]):
                 return i, True
-            if state.current_value == ',' and not state.next_value.isdigit():
+            if state.current_value == ',' and self.blank.match(state.next_value):
                 # -- 首字母大写优先切分 -- #
                 if state[min(i + 2, length)][0].isupper():
                     best_i = i
